@@ -1,23 +1,8 @@
-/***************************************************************************
- *   This file is part of KDevelop                                         *
- *   Copyright 2014 Gregor Vollmer <gregor@celement.de>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Gregor Vollmer <gregor@celement.de>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "cythonsyntaxremover.h"
 #include "astdefaultvisitor.h"
@@ -50,11 +35,11 @@ public:
         for (auto it = m_deletedRanges.begin();
              it !=  m_deletedRanges.end();
              it++) {
-            qSort(it.value().begin(),  it.value().end());
+            std::sort(it.value().begin(),  it.value().end());
         }
     }
 
-    virtual void visitIdentifier(Identifier* node) {
+    void visitIdentifier(Identifier* node) override {
         if (node) {
             fixIdentifier(node);
         }
